# Using the MCP Server for Tech Stack Management
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/using-mcp-server-for-tech-stack-management#overview)
  * [Benefits](https://help.sap.com/docs/leanix/ea/using-mcp-server-for-tech-stack-management#benefits)
  * [Permissions](https://help.sap.com/docs/leanix/ea/using-mcp-server-for-tech-stack-management#permissions)
  * [Example Use Cases](https://help.sap.com/docs/leanix/ea/using-mcp-server-for-tech-stack-management#example-use-cases)


Manage tech stack data programmatically through the MCP server.
